// Presenter: user.component.ts

import { Component, OnInit } from '@angular/core';
import { User, UserService } from './user.service';
import { FormGroup, FormControl, Validators } from '@angular/forms';

@Component({
    selector: 'app-user',
    template: './user.component.html',
})
export class UserComponent implements OnInit {
    user: User;
    form: FormGroup;

    constructor(private userService: UserService) { }

    ngOnInit() {
        this.userService.getUser().subscribe(user => {
            this.user = user;
        });
        this.form = new FormGroup({
            name: new FormControl('', Validators.required),
            age: new FormControl('', [Validators.required, Validators.min(1)])
        });
    }

    submit(): void {
        if (this.form.valid) {
            this.form.addControl(
                'ageColor',
                new FormControl(this.userService.getColorByAge(this.form.get('age').value))
            );
            this.userService.createUser((this.form.value) as User);
        }
    }
}